@@ -121,14 +121,14 @@ typedef struct {
 
 /* Mapping of event names to option flags and event_t types */
 static const ev_map_t ev_map[] = {
-	{ "fork", "Fork", OPT_EV_FORK, STAT_FORK },
-	{ "exec", "Exec", OPT_EV_EXEC, STAT_EXEC },
-	{ "exit", "Exit", OPT_EV_EXIT, STAT_EXIT },
-	{ "core", "Coredump", OPT_EV_CORE, STAT_CORE },
-	{ "comm", "Comm", OPT_EV_COMM, STAT_COMM },
-	{ "clone","Clone", OPT_EV_CLNE, STAT_CLNE },
-	{ "all",  ""	, OPT_EV_ALL,   0 },
-	{ NULL  ,  NULL,   0,           0 }
+	{ "fork", "Fork", 	OPT_EV_FORK,	STAT_FORK },
+	{ "exec", "Exec", 	OPT_EV_EXEC,	STAT_EXEC },
+	{ "exit", "Exit", 	OPT_EV_EXIT,	STAT_EXIT },
+	{ "core", "Coredump",	OPT_EV_CORE,	STAT_CORE },
+	{ "comm", "Comm", 	OPT_EV_COMM,	STAT_COMM },
+	{ "clone","Clone",	OPT_EV_CLNE,	STAT_CLNE },
+	{ "all",  "",		OPT_EV_ALL,	0 },
+	{ NULL,	  NULL, 	0,		0 }
 };
 
 #define KERN_TASK_INFO(str)	{ str, sizeof(str) - 1 }
@@ -240,7 +240,7 @@ static pid_t get_parent_pid(const pid_t pid, bool *is_thread)
 			}
 		}
 	}
-	fclose(fp);
+	(void)fclose(fp);
 
 	if ((got & GOT_ALL) == GOT_ALL) {
 		/*  TGID and PID are not the same if it is a thread */
@@ -320,7 +320,7 @@ static bool pid_a_kernel_thread(const char *task, const pid_t id)
 		 * Until we have better kernel support to map /proc/timer_stats
 		 * pids to containerised pids this is the best we can do.
 		 */
-		static kernel_task_info kernel_tasks[] = {
+		static const kernel_task_info kernel_tasks[] = {
 			KERN_TASK_INFO("swapper/"),
 			KERN_TASK_INFO("kworker/"),
 			KERN_TASK_INFO("ksoftirqd/"),
@@ -414,7 +414,7 @@ static inline double timeval_to_double(const struct timeval *tv)
  *  proc_info_hash()
  * 	hash on PID
  */
-static inline int proc_info_hash(const pid_t pid)
+static inline size_t proc_info_hash(const pid_t pid)
 {
 	return pid % MAX_PIDS;
 }
@@ -483,8 +483,8 @@ static void proc_stats_account(const pid_t pid, const event_t event)
  */
 static int stats_cmp(const void *v1, const void *v2)
 {
-	proc_stats_t **s1 = (proc_stats_t **)v1;
-	proc_stats_t **s2 = (proc_stats_t **)v2;
+	proc_stats_t *const *s1 = (proc_stats_t *const *)v1;
+	proc_stats_t *const *s2 = (proc_stats_t *const *)v2;
 
 	if ((*s2)->total == (*s1)->total)
 		return 0;
@@ -498,8 +498,7 @@ static int stats_cmp(const void *v1, const void *v2)
  */
 static void proc_stats_report(void)
 {
-	int i;
-	int n = 0;
+	size_t i, n = 0;
 	proc_stats_t *stats, **sorted;
 
 	if (!(opt_flags & OPT_STATS))
@@ -547,7 +546,7 @@ static void proc_stats_report(void)
  */
 static void proc_stats_free(void)
 {
-	int i;
+	size_t i;
 
 	for (i = 0; i < MAX_PIDS; i++) {
 		proc_stats_t *stats = proc_stats[i];
@@ -646,7 +645,7 @@ static char *proc_cmdline(const pid_t pid)
  */
 static proc_info_t *proc_info_get(const pid_t pid)
 {
-	int i = proc_info_hash(pid);
+	size_t i = proc_info_hash(pid);
 	proc_info_t *info = proc_info[i];
 
 	while (info) {
@@ -663,7 +662,7 @@ static proc_info_t *proc_info_get(const pid_t pid)
  */
 static void proc_info_free(const pid_t pid)
 {
-	int i = proc_info_hash(pid);
+	size_t i = proc_info_hash(pid);
 	proc_info_t *info = proc_info[i];
 
 	while (info) {
@@ -683,7 +682,7 @@ static void proc_info_free(const pid_t pid)
  */
 static void proc_info_unload(void)
 {
-	int i;
+	size_t i;
 
 	for (i = 0; i < MAX_PIDS; i++) {
 		proc_info_t *info = proc_info[i];
@@ -723,7 +722,7 @@ static proc_info_t const *proc_info_update(const pid_t pid)
  */
 static proc_info_t *proc_info_add(const pid_t pid, struct timeval *tv)
 {
-	int i = proc_info_hash(pid);
+	size_t i = proc_info_hash(pid);
 	proc_info_t *info;
 	char *cmdline;
 
@@ -1162,12 +1161,12 @@ static void show_help(char *const argv[])
  *  parse_ev()
  *	parse event strings, turn into flag mask
  */
-static int parse_ev(const char *arg)
+static int parse_ev(char *arg)
 {
 	char *str, *token;
 
-	for (str = (char*)arg; (token = strtok(str, ",")) != NULL; str = NULL) {
-		int i;
+	for (str = arg; (token = strtok(str, ",")) != NULL; str = NULL) {
+		size_t i;
 		bool found = false;
 
 		for (i = 0; ev_map[i].event; i++) {
@@ -1186,7 +1185,8 @@ static int parse_ev(const char *arg)
 
 int main(int argc, char * const argv[])
 {
-	int i, sock = -1, ret = EXIT_FAILURE;
+	size_t i;
+	int sock = -1, ret = EXIT_FAILURE;
 	struct sigaction new_action;
 
 	for (;;) {
